PipelineExceptionHandler class

Annotation for a pipeline exception handler function.

Inheritance

Constructors

PipelineExceptionHandler({String? pipeline})
Constructor for pipeline exception handler annotations.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pipeline → String
Name of the pipeline for the exception handler.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited