Handles.request constructor
Constructor with a specific HTTP method.
The httpMethod is the name of the HTTP method, and pattern is the
string representation of the pattern to match. The optional pipeline
name identifies the pipeline the rule is for, and priority controls
the order in which the rule is added to the pipeline.
Implementation
const Handles.request(this.httpMethod, this.pattern,
{String? pipeline, int? priority})
: pipeline = pipeline ?? ServerPipeline.defaultName,
priority = priority ?? 0;