NoResponseProduced class

Indicates a handler cannot produce a response.

This is not necessarily an error: it just means that particular handler function expects some other function to produce the response.

For request handlers, the function expects another handler in the pipeline, or a subsequent pipeline, to further process the request.

Note: before null safety handlers used to return null to indicate a response was not produced. With null safety the handlers cannot return null, so they throw this exception instead.

Inheritance

Constructors

NoResponseProduced()
Constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited