DuplicateRuleWithExistingHandler class

Attempt to register a duplicate rule in a pipeline.

This class extends DuplicateRule when the Mirrors package is available to describe the existing handler.

Inheritance
Annotations
  • @Deprecated('The woomera:scan library has been deprecated.')

Constructors

DuplicateRuleWithExistingHandler(String method, Pattern pattern, RequestHandler newHandler, RequestHandler existingHandler)
Constructor

Properties

existingHandler → RequestHandler
The request handler that has already been registered in the pipeline.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
method → String
HTTP method
finalinherited
newHandler → RequestHandler
The new request handler being registered.
finalinherited
pattern → Pattern
Path
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited