NotRequestHandler class

Indicates an Handles annotation was place on the wrong type of function.

The type signature of the function or method was not the RequestHandler function type.

Inheritance
Annotations
  • @Deprecated('The woomera:scan library has been deprecated.')

Constructors

NotRequestHandler(SourceLocation location, String name, Handles annotation)
Constructor

Properties

annotation → Handles
The annotation
final
hashCode → int
The hash code for this object.
no setterinherited
location → SourceLocation
Library where the function was defined.
final
name → String
Name of the function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited